(new-contributors-guide)=
# Guide for New Contributors

This guide goes over how to contribute code to SymPy for new contributors.

This guide is split into sections based on how experienced you are with open source.

If you have never contributed to an open source project before, start with
**[](./dev-setup.md)**.

If you are already familiar with the basics of how to use git and GitHub, but
you have never contributed to SymPy before, start with
**[](./workflow-process.md)**.

## Index

```{toctree}
:titlesonly: true

dev-setup.md
workflow-process.md
writing-tests.md
build-docs.rst
```
